interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     * - `MANUAL`: Category is created manually by the user.
     * - `AUTO`: Category is created automatically.
     * - `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * - `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
interface CategoryCounts {
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedEventsCount?: number | null;
    /** Total number of draft events assigned to the category. */
    assignedDraftEventsCount?: number | null;
}
declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
interface CreateCategoryRequest {
    /** Category to create. */
    category: Category;
}
interface CreateCategoryResponse {
    /** Created category. */
    category?: Category;
}
interface BulkCreateCategoryRequest {
    /**
     * Categories to create.
     * @minSize 1
     * @maxSize 10
     */
    categories: Category[];
}
interface BulkCreateCategoryResponse {
    /** Bulk create results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkCategoryResult {
    /** Metadata. */
    itemMetadata?: ItemMetadata;
    /** Created categories. */
    item?: Category;
}
interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    _id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details due to exceeding the threshold for detailed failures. */
    undetailedFailures?: number;
}
interface UpdateCategoryRequest {
    /** Category to update. */
    category: Category;
}
interface UpdateCategoryResponse {
    /** Updated category. */
    category?: Category;
}
interface DeleteCategoryRequest {
    /**
     * ID of category to be deleted.
     * @format GUID
     */
    categoryId: string;
}
interface DeleteCategoryResponse {
}
interface QueryCategoriesRequest {
    /** Options to use when querying categories. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[];
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
     * See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events).
     * @maxSize 20
     */
    sort?: Sorting[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
}
interface Sorting {
    /**
     * Name of the field to sort by
     * @maxLength 100
     */
    fieldName?: string;
    /** Sort order (ASC/DESC). Defaults to ASC */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /**
     * Number of items to load per page.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
declare enum CategoryFieldset {
    /** Include `assignedEventsCount` in the response. */
    COUNTS = "COUNTS"
}
/** @enumType */
type CategoryFieldsetWithLiterals = CategoryFieldset | 'COUNTS';
interface QueryCategoriesResponse {
    /** List of categories. */
    categories?: Category[];
    /** Metadata for the paginated results. */
    metaData?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface AssignEventsRequest {
    /**
     * ID of category to which events should be assigned.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
interface AssignEventsResponse {
}
interface BulkAssignEventsRequest {
    /**
     * A list of category IDs to which events should be assigned.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
interface BulkAssignEventsResponse {
    /** Bulk assign results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkAssignEventsAsyncRequest {
    /**
     * Category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
interface BulkAssignEventsAsyncResponse {
}
interface UnassignEventsRequest {
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
interface UnassignEventsResponse {
}
interface BulkUnassignEventsRequest {
    /**
     * A list of category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
interface BulkUnassignEventsResponse {
    /** Results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUnassignEventsAsyncRequest {
    /**
     * Category ID.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
interface BulkUnassignEventsAsyncResponse {
}
interface ListEventCategoriesRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
}
interface ListEventCategoriesResponse {
    /** A list of categories. */
    categories?: Category[];
}
interface ReorderCategoryEventsRequest extends ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
}
/** @oneof */
interface ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
interface ReorderCategoryEventsResponse {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface UpdateCategory {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     * - `MANUAL`: Category is created manually by the user.
     * - `AUTO`: Category is created automatically.
     * - `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * - `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
interface QueryCategoriesOptions {
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[] | undefined;
}
interface QueryOffsetResult {
    currentPage: number | undefined;
    totalPages: number | undefined;
    totalCount: number | undefined;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface CategoriesQueryResult extends QueryOffsetResult {
    items: Category[];
    query: CategoriesQueryBuilder;
    next: () => Promise<CategoriesQueryResult>;
    prev: () => Promise<CategoriesQueryResult>;
}
interface CategoriesQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    eq: (propertyName: '_id' | 'name', value: any) => CategoriesQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     */
    hasSome: (propertyName: string, value: any[]) => CategoriesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    ascending: (...propertyNames: Array<'_createdDate'>) => CategoriesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    descending: (...propertyNames: Array<'_createdDate'>) => CategoriesQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object. */
    limit: (limit: number) => CategoriesQueryBuilder;
    /** @param skip - Number of items to skip in the query results before returning the results. */
    skip: (skip: number) => CategoriesQueryBuilder;
    find: () => Promise<CategoriesQueryResult>;
}
interface BulkAssignEventsOptions {
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
interface BulkAssignEventsAsyncOptions {
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
interface BulkUnassignEventsOptions {
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
interface BulkUnassignEventsAsyncOptions {
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
interface ReorderCategoryEventsOptions extends ReorderCategoryEventsOptionsReferenceEventOneOf {
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
/** @oneof */
interface ReorderCategoryEventsOptionsReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}

export { type EntityCreatedEvent as $, type ApplicationError as A, type BulkCreateCategoryResponse as B, type Category as C, type DeleteCategoryRequest as D, type AssignEventsResponse as E, type BulkAssignEventsRequest as F, type BulkAssignEventsAsyncRequest as G, type BulkAssignEventsAsyncResponse as H, type ItemMetadata as I, type UnassignEventsRequest as J, type UnassignEventsResponse as K, type ListEventCategoriesResponse as L, type BulkUnassignEventsRequest as M, type BulkUnassignEventsAsyncRequest as N, type BulkUnassignEventsAsyncResponse as O, type Paging as P, type QueryCategoriesOptions as Q, type ReorderCategoryEventsOptions as R, State as S, type ListEventCategoriesRequest as T, type UpdateCategory as U, type ReorderCategoryEventsRequest as V, WebhookIdentityType as W, type ReorderCategoryEventsRequestReferenceEventOneOf as X, type ReorderCategoryEventsResponse as Y, type DomainEvent as Z, type DomainEventBodyOneOf as _, type CategoriesQueryBuilder as a, type RestoreInfo as a0, type EntityUpdatedEvent as a1, type EntityDeletedEvent as a2, type ActionEvent as a3, type MessageEnvelope as a4, type IdentificationData as a5, type IdentificationDataIdOneOf as a6, type CategoriesQueryResult as a7, type ReorderCategoryEventsOptionsReferenceEventOneOf as a8, type BulkAssignEventsOptions as b, type BulkAssignEventsResponse as c, type BulkAssignEventsAsyncOptions as d, type BulkUnassignEventsOptions as e, type BulkUnassignEventsResponse as f, type BulkUnassignEventsAsyncOptions as g, SortOrder as h, CategoryFieldset as i, type CategoryCounts as j, type CreateCategoryRequest as k, type CreateCategoryResponse as l, type BulkCreateCategoryRequest as m, type BulkCategoryResult as n, type BulkActionMetadata as o, type UpdateCategoryRequest as p, type UpdateCategoryResponse as q, type DeleteCategoryResponse as r, type QueryCategoriesRequest as s, type QueryV2 as t, type QueryV2PagingMethodOneOf as u, type Sorting as v, type QueryCategoriesResponse as w, type PagingMetadataV2 as x, type Cursors as y, type AssignEventsRequest as z };
